<?php

use EventPortal\Http\Controllers\Delegate\Account\AccountController;
use EventPortal\Http\Controllers\Delegate\Account\ChangePasswordController;
use EventPortal\Http\Controllers\Delegate\DashboardController;
use EventPortal\Http\Controllers\Delegate\Event\AgendaController;
use EventPortal\Http\Controllers\Delegate\Event\CancelledController;
use EventPortal\Http\Controllers\Delegate\Event\ContactController;
use EventPortal\Http\Controllers\Delegate\Event\FaqController;
use EventPortal\Http\Controllers\Delegate\Event\Form\StoreFormController;
use EventPortal\Http\Controllers\Delegate\Event\Form\UpdateFormController;
use EventPortal\Http\Controllers\Delegate\Event\Form\ViewFormController;
use EventPortal\Http\Controllers\Delegate\Event\LandingController;
use EventPortal\Http\Controllers\Delegate\Event\VenueController;
use EventPortal\Http\Middleware\CanDelegateViewForm;
use EventPortal\Http\Middleware\Event\EventIsNotCancelled;
use EventPortal\Http\Middleware\Event\InViewableStatus;

Route::get('', [DashboardController::class, '__invoke'])->name('home');

Route::get('/account', [AccountController::class, '__invoke'])->name('account.index');
Route::post('/account/change-password', [ChangePasswordController::class, '__invoke'])->name('account.password.update');

Route::get('event/{event}/cancelled', [CancelledController::class, '__invoke'])->name('event.cancelled');

Route::prefix('event/{event}')
    ->middleware([InViewableStatus::class, EventIsNotCancelled::class])
    ->group(function (): void {
        Route::get('/', [LandingController::class, '__invoke'])->name('delegate.landing');
        Route::get('/agenda', [AgendaController::class, '__invoke'])->name('agenda.index');
        Route::get('/venue', [VenueController::class, '__invoke'])->name('venue.index');
        Route::get('/faqs', [FaqController::class, '__invoke'])->name('faq.index');
        Route::get('contact', [ContactController::class, 'index'])->name('contact.index');
        Route::post('contact', [ContactController::class, 'store'])->name('contact.store');

        Route::prefix('{form}')
            ->middleware(CanDelegateViewForm::class)
            ->group(function (): void {
                Route::get('/{stepOrder?}', [ViewFormController::class, '__invoke'])->name('delegate.form.index');
                Route::post('{step}/store', [StoreFormController::class, '__invoke'])->name('delegate.form.store');
                Route::post('{step}/update', [UpdateFormController::class, '__invoke'])->name('delegate.form.update');
            });
    });
