<?php

namespace EventPortal\Domain\Util;

use EventPortal\Domain\Event\ValueObjects\PageHeader;
use EventPortal\Domain\FormProgress\FormProgress;
use EventPortal\Domain\Speaker\Models\Speaker;
use EventPortal\Domain\Venue\Models\Venue;
use Illuminate\Support\Collection;

class DelegateRender extends Render
{
    public static function component(string $component, string $context = 'delegate'): self
    {
        return new self($component, $context);
    }

    public function withPageHeader(PageHeader $pageHeader): self
    {
        $this->data['pageHeader'] = $pageHeader->toArray();

        return $this;
    }

    public function withSpeakers(?Collection $speakers): self
    {
        $this->data['speakers'] = [
            'title' => 'Speakers',
            'list' => $speakers->map(function (Speaker $speaker) {
                return [
                    'name' => $speaker->name,
                    'title' => $speaker->job_title,
                    'description' => $speaker->bio,
                ];
            }),
        ];

        return $this;
    }

    public function withVenues(?Collection $venues): self
    {
        $this->data['venues'] = [
            'title' => 'Venues',
            'list' => $venues->map(function (Venue $venue) {
                return [
                    'name' => $venue->name,
                    'description' => $venue->description,
                    'link' => $venue->website,
                    'button' => null,
                    'address' => optional($venue->address)->formatted,
                ];
            }),
        ];

        return $this;
    }

    public function withFormProgress(?FormProgress $formProgress = null): self
    {
        $this->data['formProgress'] = $formProgress;

        return $this;
    }
}
