<?php

namespace EventPortal\Http\Controllers\Admin\EventDelegate;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\AdminRender;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Domain\Util\QuickButtons\Facades\QuickButtons;
use EventPortal\Domain\Util\Sidebar\Facades\Sidebar;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Database\Query\JoinClause;
use Inertia\Response;

class EventDelegateController extends Controller
{
    public function index(Event $event): Response
    {
        $query = Delegate::query()
            ->join('delegate_event', function (JoinClause $query) {
                return $query->on('delegates.id', '=', 'delegate_event.delegate_id');
            })
            ->joinRelationship('user')
            ->where('delegate_event.event_id', '=', $event->id);

        $table = Table::make('event-delegate.index')
            ->context($event)
            ->query($query)
            ->request(request())
            ->get();

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('admin.event.index'))
            ->add($event->name, route('admin.event.show', $event))
            ->add('Delegates')
            ->get();

        $sidebar = Sidebar::make('event.show')
            ->user(auth()->user())
            ->model($event)
            ->status(optional($event->approval)->getStatusTitleAttribute())
            ->render();

        $quickButtons = QuickButtons::make('event-delegate.index')->context($event)->get();

        return AdminRender::component('Admin/EventDelegate/Index')
            ->key('event.delegate.index')
            ->withTable($table)
            ->withBreadcrumbs($breadcrumbs)
            ->withSideBar($sidebar)
            ->attributes(['event' => $event])
            ->withQuickButtons($quickButtons)
            ->get();
    }

    public function show(Event $event, Delegate $delegate): Response
    {
        $delegate->loadMissing('address');

        $eventDelegate = EventDelegate::forEventAndDelegate($event, $delegate)->first();

        $delegateData = Form::make('event-delegate.show')
            ->model($delegate)
            ->context($event, $eventDelegate)
            ->render();

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('admin.event.index'))
            ->add($event->name, route('admin.event.show', $event))
            ->add('View Delegate')
            ->get();

        $sidebar = Sidebar::make('event.show')
            ->user(auth()->user())
            ->model($event)
            ->render();

        return AdminRender::component('Admin/EventDelegate/Show')
            ->key('event.delegate.show')
            ->withData($delegateData)
            ->withBreadcrumbs($breadcrumbs)
            ->withTitle($delegate->name)
            ->withSideBar($sidebar)
            ->get();
    }
}
